==> haskell-hspec-attoparsec-0.1.0.2-90-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hspec-attoparsec.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hspec-attoparsec
version:              0.1.0.2
visibility:           public
id:                   hspec-attoparsec-0.1.0.2-p4MebP4Q6RFicGivRdK53
key:                  hspec-attoparsec-0.1.0.2-p4MebP4Q6RFicGivRdK53
license:              BSD-3-Clause
copyright:            2014-2015 Alp Mestanogullari
maintainer:           alpmestan@gmail.com
author:               Alp Mestanogullari
homepage:             http://github.com/alpmestan/hspec-attoparsec
synopsis:
    Utility functions for testing your attoparsec parsers with hspec

description:
    This package provides some helper functions for testing attoparsec parsers with hspec.

    See the documentation in @Test.Hspec.Attoparsec@ for examples, or this package'\''s own test suite.

category:             Testing, Parsing
abi:                  0dda86a8939b1c50bc5746c033a8b131
exposed:              True
exposed-modules:      Test.Hspec.Attoparsec Test.Hspec.Attoparsec.Source
import-dirs:          /usr/lib/ghc-9.0.1/site-local/hspec-attoparsec-0.1.0.2
library-dirs:         /usr/lib/ghc-9.0.1/site-local/hspec-attoparsec-0.1.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/hspec-attoparsec-0.1.0.2
hs-libraries:         HShspec-attoparsec-0.1.0.2-p4MebP4Q6RFicGivRdK53
depends:
    attoparsec-0.14.1-K1PNUn1z9Ub7TsFBpn3sHF base-4.15.0.0
    bytestring-0.10.12.1
    hspec-expectations-0.8.2-GGGXL2nWs981V3xvQdYYx0 text-1.2.4.1

haddock-interfaces:
    /usr/share/doc/haskell-hspec-attoparsec/html/hspec-attoparsec.haddock

haddock-html:         /usr/share/doc/haskell-hspec-attoparsec/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hspec-attoparsec-0.1.0.2-91-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hspec-attoparsec.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hspec-attoparsec
version:              0.1.0.2
visibility:           public
id:                   hspec-attoparsec-0.1.0.2-CY9zKHZAIDJAzItWVAsB4r
key:                  hspec-attoparsec-0.1.0.2-CY9zKHZAIDJAzItWVAsB4r
license:              BSD-3-Clause
copyright:            2014-2015 Alp Mestanogullari
maintainer:           alpmestan@gmail.com
author:               Alp Mestanogullari
homepage:             http://github.com/alpmestan/hspec-attoparsec
synopsis:
    Utility functions for testing your attoparsec parsers with hspec

description:
    This package provides some helper functions for testing attoparsec parsers with hspec.

    See the documentation in @Test.Hspec.Attoparsec@ for examples, or this package'\''s own test suite.

category:             Testing, Parsing
abi:                  b895110d7532feab87bd017291f5595f
exposed:              True
exposed-modules:      Test.Hspec.Attoparsec Test.Hspec.Attoparsec.Source
import-dirs:          /usr/lib/ghc-9.0.1/site-local/hspec-attoparsec-0.1.0.2
library-dirs:         /usr/lib/ghc-9.0.1/site-local/hspec-attoparsec-0.1.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/hspec-attoparsec-0.1.0.2
hs-libraries:         HShspec-attoparsec-0.1.0.2-CY9zKHZAIDJAzItWVAsB4r
depends:
    attoparsec-0.14.1-HerROSs0hpLEq1E44JWFyp base-4.15.0.0
    bytestring-0.10.12.1
    hspec-expectations-0.8.2-K2KY3C8ipz3Kpo8fmEqriR text-1.2.4.1

haddock-interfaces:
    /usr/share/doc/haskell-hspec-attoparsec/html/hspec-attoparsec.haddock

haddock-html:         /usr/share/doc/haskell-hspec-attoparsec/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
